@@ -1,4 +1,4 @@
-# Copyright (C) 2013  Ruby-GNOME2 Project Team
+# Copyright (C) 2013-2019  Ruby-GNOME Project Team
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,10 @@ class NativePackageInstaller
 
       class << self
         def current_platform?
-          File.exist?("/etc/debian_version")
+          return false unless File.exist?("/etc/os-release")
+          File.readlines("/etc/os-release").any? do |line|
+            line.chomp == "ID=debian"
+          end
         end
       end
 
